==> vtk-6.3.0-5-armv7h.pkg.tar.xz: vtk/vtkProteinRibbonFilter.java <==
// java wrapper for vtkProteinRibbonFilter object
//

package vtk;
import vtk.*;

public class vtkProteinRibbonFilter extends vtkPolyDataAlgorithm
{

  private native String GetClassName_0();
  public String GetClassName()
    { return GetClassName_0(); }

  private native int IsA_1(String id0);
  public int IsA(String id0)
    { return IsA_1(id0); }

  private native double GetCoilWidth_2();
  public double GetCoilWidth()
    { return GetCoilWidth_2(); }

  private native void SetCoilWidth_3(double id0);
  public void SetCoilWidth(double id0)
    { SetCoilWidth_3(id0); }

  private native double GetHelixWidth_4();
  public double GetHelixWidth()
    { return GetHelixWidth_4(); }

  private native void SetHelixWidth_5(double id0);
  public void SetHelixWidth(double id0)
    { SetHelixWidth_5(id0); }

  private native int GetSubdivideFactor_6();
  public int GetSubdivideFactor()
    { return GetSubdivideFactor_6(); }

  private native void SetSubdivideFactor_7(int id0);
  public void SetSubdivideFactor(int id0)
    { SetSubdivideFactor_7(id0); }

  private native boolean GetDrawSmallMoleculesAsSpheres_8();
  public boolean GetDrawSmallMoleculesAsSpheres()
    { return GetDrawSmallMoleculesAsSpheres_8(); }

  private native void SetDrawSmallMoleculesAsSpheres_9(boolean id0);
  public void SetDrawSmallMoleculesAsSpheres(boolean id0)
    { SetDrawSmallMoleculesAsSpheres_9(id0); }

  private native int GetSphereResolution_10();
  public int GetSphereResolution()
    { return GetSphereResolution_10(); }

  private native void SetSphereResolution_11(int id0);
  public void SetSphereResolution(int id0)
    { SetSphereResolution_11(id0); }

  public vtkProteinRibbonFilter() { super(); }

  public vtkProteinRibbonFilter(long id) { super(id); }
  public native long   VTKInit();

}

==> vtk-8.2.0-20-armv7h.pkg.tar.xz: vtk/vtkProteinRibbonFilter.java <==
// java wrapper for vtkProteinRibbonFilter object
//

package vtk;
import vtk.*;

public class vtkProteinRibbonFilter extends vtkPolyDataAlgorithm
{

  private native int IsTypeOf_0(String id0);
  public int IsTypeOf(String id0)
    { return IsTypeOf_0(id0); }

  private native int IsA_1(String id0);
  public int IsA(String id0)
    { return IsA_1(id0); }

  private native double GetCoilWidth_2();
  public double GetCoilWidth()
    { return GetCoilWidth_2(); }

  private native void SetCoilWidth_3(double id0);
  public void SetCoilWidth(double id0)
    { SetCoilWidth_3(id0); }

  private native double GetHelixWidth_4();
  public double GetHelixWidth()
    { return GetHelixWidth_4(); }

  private native void SetHelixWidth_5(double id0);
  public void SetHelixWidth(double id0)
    { SetHelixWidth_5(id0); }

  private native int GetSubdivideFactor_6();
  public int GetSubdivideFactor()
    { return GetSubdivideFactor_6(); }

  private native void SetSubdivideFactor_7(int id0);
  public void SetSubdivideFactor(int id0)
    { SetSubdivideFactor_7(id0); }

  private native boolean GetDrawSmallMoleculesAsSpheres_8();
  public boolean GetDrawSmallMoleculesAsSpheres()
    { return GetDrawSmallMoleculesAsSpheres_8(); }

  private native void SetDrawSmallMoleculesAsSpheres_9(boolean id0);
  public void SetDrawSmallMoleculesAsSpheres(boolean id0)
    { SetDrawSmallMoleculesAsSpheres_9(id0); }

  private native int GetSphereResolution_10();
  public int GetSphereResolution()
    { return GetSphereResolution_10(); }

  private native void SetSphereResolution_11(int id0);
  public void SetSphereResolution(int id0)
    { SetSphereResolution_11(id0); }

  public vtkProteinRibbonFilter() { super(); }

  public vtkProteinRibbonFilter(long id) { super(id); }
  public native long   VTKInit();

}
